from .objekt import Objekt
from .vegreferanse import Vegreferanse
from .area import Area
from .objekt_type import Objekt_type
from .posisjon import Posisjon
__all__ = ('Objekt','Vegreferanse', 'Area', 'objekt_type', 'posisjon')